Module cache

Module cache 

Structs

CacheEntry
StaleCacheRead
A cached entry plus whether it is past the freshness TTL.

Functions

cache_file_for_target
clear_prompt_segment_cache
read_cache_entry
read_cache_entry_allow_stale
Reads the cached entry without rejecting stale data, reporting whether it is past the freshness TTL.
read_cache_entry_for_cached_mode
secret_name_for_target
write_prompt_segment_cache