Structs
- Cache
Entry - Stale
Cache Read - A cached entry plus whether it is past the freshness TTL.
Functions
- cache_
file_ for_ target - clear_
prompt_ segment_ cache - read_
cache_ entry - read_
cache_ entry_ allow_ stale - Reads the cached entry without rejecting stale data, reporting whether it is past the freshness TTL.
- read_
cache_ entry_ for_ cached_ mode - secret_
name_ for_ target - write_
prompt_ segment_ cache